==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ApplyButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescription } from "./ApplyButtonClickEventArgsDescription";
/**
 * @hidden
 */
var ApplyButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ApplyButtonClickEventArgsDescriptionMetadata, _super);
    function ApplyButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ApplyButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (ApplyButtonClickEventArgsDescriptionMetadata.a == null) {
            ApplyButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ApplyButtonClickEventArgsDescriptionMetadata.c(ApplyButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.j(ApplyButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ApplyButtonClickEventArgsDescriptionMetadata.a);
    };
    ApplyButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    ApplyButtonClickEventArgsDescriptionMetadata.d = function (a) {
        ApplyButtonClickEventArgsDescriptionMetadata.b(a);
        a.aa("ApplyButtonClickEventArgs", function () { return new ApplyButtonClickEventArgsDescription(); });
        a.z("ApplyButtonClickEventArgs", ApplyButtonClickEventArgsDescriptionMetadata.a);
    };
    ApplyButtonClickEventArgsDescriptionMetadata.$t = markType(ApplyButtonClickEventArgsDescriptionMetadata, 'ApplyButtonClickEventArgsDescriptionMetadata');
    ApplyButtonClickEventArgsDescriptionMetadata.a = null;
    return ApplyButtonClickEventArgsDescriptionMetadata;
}(Base));
export { ApplyButtonClickEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ApplyButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescription } from "./ApplyButtonClickEventArgsDescription";
/**
 * @hidden
 */
var ApplyButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ApplyButtonClickEventArgsDescriptionMetadata, _super);
    function ApplyButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ApplyButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (ApplyButtonClickEventArgsDescriptionMetadata.a == null) {
            ApplyButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ApplyButtonClickEventArgsDescriptionMetadata.c(ApplyButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.k(ApplyButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(ApplyButtonClickEventArgsDescriptionMetadata.a);
    };
    ApplyButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    ApplyButtonClickEventArgsDescriptionMetadata.d = function (a) {
        ApplyButtonClickEventArgsDescriptionMetadata.b(a);
        a.ac("ApplyButtonClickEventArgs", function () { return new ApplyButtonClickEventArgsDescription(); });
        a.ab("ApplyButtonClickEventArgs", ApplyButtonClickEventArgsDescriptionMetadata.a);
    };
    ApplyButtonClickEventArgsDescriptionMetadata.$t = markType(ApplyButtonClickEventArgsDescriptionMetadata, 'ApplyButtonClickEventArgsDescriptionMetadata');
    ApplyButtonClickEventArgsDescriptionMetadata.a = null;
    return ApplyButtonClickEventArgsDescriptionMetadata;
}(Base));
export { ApplyButtonClickEventArgsDescriptionMetadata };
